summaryrefslogtreecommitdiffstats
path: root/remote-processor/RequestMessage.h
diff options
context:
space:
mode:
authorSebastien Gonzalve <oznog@zarb.org>2014-02-20 22:28:03 +0100
committerDavid Wagner <david.wagner@intel.com>2014-09-11 14:25:02 +0200
commitd9526499d6ab53b7d13d1434f748f6f2161c2e0a (patch)
tree8d2e2db275800821d4bf8873fc16b686bca60b2d /remote-processor/RequestMessage.h
parentffbf43b383bb8693741430b02c24dbc9b127f7f7 (diff)
downloadexternal_parameter-framework-d9526499d6ab53b7d13d1434f748f6f2161c2e0a.zip
external_parameter-framework-d9526499d6ab53b7d13d1434f748f6f2161c2e0a.tar.gz
external_parameter-framework-d9526499d6ab53b7d13d1434f748f6f2161c2e0a.tar.bz2
Remove using std::XXX from headers
This is a bad practice to have using in headers because it pollutes the namespace of any user of that header.
Diffstat (limited to 'remote-processor/RequestMessage.h')
-rw-r--r--remote-processor/RequestMessage.h21
1 files changed, 11 insertions, 10 deletions
diff --git a/remote-processor/RequestMessage.h b/remote-processor/RequestMessage.h
index 7104e36..17f433b 100644
--- a/remote-processor/RequestMessage.h
+++ b/remote-processor/RequestMessage.h
@@ -32,22 +32,23 @@
#include "Message.h"
#include "RemoteCommand.h"
#include <vector>
+#include <string>
class CRequestMessage : public CMessage, public IRemoteCommand
{
public:
- CRequestMessage(const string& strCommand);
+ CRequestMessage(const std::string& strCommand);
CRequestMessage();
// Command Name
- void setCommand(const string& strCommand);
- virtual const string& getCommand() const;
+ void setCommand(const std::string& strCommand);
+ virtual const std::string& getCommand() const;
// Arguments
- virtual void addArgument(const string& strArgument);
+ virtual void addArgument(const std::string& strArgument);
virtual uint32_t getArgumentCount() const;
- virtual const string& getArgument(uint32_t uiArgument) const;
- virtual const string packArguments(uint32_t uiStartArgument, uint32_t uiNbArguments) const;
+ virtual const std::string& getArgument(uint32_t uiArgument) const;
+ virtual const std::string packArguments(uint32_t uiStartArgument, uint32_t uiNbArguments) const;
private:
@@ -64,12 +65,12 @@ private:
virtual void collectReceivedData();
// Size
virtual uint32_t getDataSize() const;
- // Trim input string
- static string trim(const string& strToTrim);
+ // Trim input std::string
+ static std::string trim(const std::string& strToTrim);
// Command
- string _strCommand;
+ std::string _strCommand;
// Arguments
- vector<string> _argumentVector;
+ std::vector<std::string> _argumentVector;
};